bayespy.inference.vmp.nodes.stochastic.Stochastic.plates_multiplier
===================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. autoattribute:: Stochastic.plates_multiplier